==> imspector-0.5.tar.gz: imspector-0.5/protocolplugin.h <==
/* IMSpector - Instant Messenger Transparent Proxy Service
 * http://www.imspector.org/
 * (c) Lawrence Manning <lawrence@aslak.net>, 2006
 *          
 * Released under the GPL v2. */

struct protocolplugininfo
{
	std::string pluginname;
	std::string protocolname;
	uint16_t port; 				/* Network byte order. */
};

#define TYPE_NULL 0
#define TYPE_MSG 1
#define TYPE_FILE 2
#define TYPE_TYPING 3
#define TYPE_WEBCAM 4

struct messageextent
{
	int start;
	int length;
};

struct imevent
{
	time_t timestamp;
	std::string clientaddress;
	std::string protocolname;				/* From the protocol plugin. */
	bool outgoing;
	int type;								/* One of TYPE_ */
	std::string localid;
	std::string remoteid;
	bool filtered;
	std::string eventdata;
	struct messageextent messageextent;		/* Not used by logging plugins. */
};

typedef bool (*initprotocolplugintype)(struct protocolplugininfo &protocolplugininfo,
	class Options &options, bool debugmode);
typedef void (*closeprotocolplugintype)(void);
typedef int (*processpackettype)(bool outgoing, class Socket &incomingsock, char *replybuffer, 
	int *replybufferlength, std::vector<struct imevent> &imevents, std::string &clientaddress);

class ProtocolPlugin
{
	public:
		struct protocolplugininfo protocolplugininfo;
	
		ProtocolPlugin();
		~ProtocolPlugin();
		bool loadplugin(std::string filename);
		bool unloadplugin(void);
		
		bool callinitprotocolplugin(class Options &options, bool debugmode);
		void callcloseprotocolplugin(void);
		int callprocesspacket(bool outgoing, class Socket &incomingsock, char *replybuffer,
			int *replybufferlength, std::vector<struct imevent> &imevents, std::string &clientaddress);

	private:
		void *handle;

		initprotocolplugintype initprotocolplugin;
		closeprotocolplugintype closeprotocolplugin;
		processpackettype processpacket;
};

==> imspector-0.7.tar.gz: imspector-0.7/protocolplugin.h <==
/* IMSpector - Instant Messenger Transparent Proxy Service
 * http://www.imspector.org/
 * (c) Lawrence Manning <lawrence@aslak.net>, 2006
 *          
 * Released under the GPL v2. */

struct protocolplugininfo
{
	std::string pluginname;
	std::string protocolname;
	uint16_t port; 				/* Network byte order. */
#ifdef HAVE_SSL
	uint16_t sslport;
#endif
};

#define TYPE_NULL 0
#define TYPE_MSG 1
#define TYPE_FILE 2
#define TYPE_TYPING 3
#define TYPE_WEBCAM 4

struct messageextent
{
	int start;
	int length;
};

struct imevent
{
	time_t timestamp;						/* UNIX timestamp. */
	std::string clientaddress;				/* IP:Port */
	std::string protocolname;				/* From the protocol plugin. */
	bool outgoing;							/* Event is local->remote. */
	int type;								/* One of TYPE_ */
	std::string localid;					/* Local party. */
	std::string remoteid;					/* Remote party. */
	bool filtered;							/* Filter plugin blocked event. */
	std::string categories;					/* Filter plugins append here. */
	std::string eventdata;					/* Usually message text. */
	struct messageextent messageextent;		/* Not used by logging plugins. */
};

typedef bool (*initprotocolplugintype)(struct protocolplugininfo &protocolplugininfo,
	class Options &options, bool debugmode);
typedef void (*closeprotocolplugintype)(void);
typedef int (*processpackettype)(bool outgoing, class Socket &incomingsock, char *replybuffer, 
	int *replybufferlength, std::vector<struct imevent> &imevents, std::string &clientaddress);

class ProtocolPlugin
{
	public:
		struct protocolplugininfo protocolplugininfo;
	
		ProtocolPlugin();
		~ProtocolPlugin();
		bool loadplugin(std::string filename);
		bool unloadplugin(void);
		
		bool callinitprotocolplugin(class Options &options, bool debugmode);
		void callcloseprotocolplugin(void);
		int callprocesspacket(bool outgoing, class Socket &incomingsock, char *replybuffer,
			int *replybufferlength, std::vector<struct imevent> &imevents, std::string &clientaddress);

	private:
		void *handle;

		initprotocolplugintype initprotocolplugin;
		closeprotocolplugintype closeprotocolplugin;
		processpackettype processpacket;
};
